using LandblockExtraction.Tools;

namespace Test_LandblockExtraction.ToolsTest {
    [TestClass]
    public class MathOperations_Test {
        [TestMethod]
        public void GetXLanfblock_CorrectlyReturn() {
            uint value = MathOperations.GetXLandblock(0x4466FFFF);

            Assert.AreEqual<uint>(0x44, value);
        }
        [TestMethod]
        public void GetYLanfblock_CorrectlyReturn() {
            uint value = MathOperations.GetYLandblock(0x4466FFFF);

            Assert.AreEqual<uint>(0x66, value);
        }
        [TestMethod]
        public void GetTerrainInCellInfo_CorrectlyReturn() {
            uint value = MathOperations.GetTerrainInCellInfo(8323074);

            Assert.AreEqual<uint>(0x2, value);
        }
        [TestMethod]
        public void GetColorInCellInfo_CorrectlyReturn() {
            uint value = MathOperations.GetColorInCellInfo(8323074);

            Assert.AreEqual<uint>(0x7F, value);
        }
        [TestMethod]
        public void GetRoadInCellInfo_CorrectlyReturn() {
            uint value = MathOperations.GetRoadInCellInfo(8323074);

            Assert.AreEqual<uint>(0x0, value);
        }
        [TestMethod]
        public void GetSceneInCellInfo_CorrectlyReturn() {
            uint value = MathOperations.GetSceneInCellInfo(8323074);

            Assert.AreEqual<uint>(0x0, value);
        }
    }
}
